"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileOverwrites = void 0;
const nbnf_1 = require("@nlib/nbnf");
const timeToNumber_1 = require("./timeToNumber");
const getFillMode_1 = require("./getFillMode");
const getTimingFunction_1 = require("./getTimingFunction");
const getDirection_1 = require("./getDirection");
const overwrite = (key, value, overwrites, property) => {
    if (key in overwrites) {
        throw new Error(`Unexpected ${key}: ${nbnf_1.nodeToString(property)}`);
    }
    overwrites[key] = value;
};
exports.compileOverwrites = (overwrites, property) => {
    switch (property.name) {
        case 'Time':
            if ('duration' in overwrites) {
                overwrite('delay', timeToNumber_1.timeToNumber(property), overwrites, property);
            }
            else {
                overwrite('duration', timeToNumber_1.timeToNumber(property), overwrites, property);
            }
            break;
        case 'KeyframesName':
            overwrite('name', nbnf_1.nodeToString(property), overwrites, property);
            break;
        case 'SingleAnimationFillMode':
            if ('fillMode' in overwrites) {
                overwrite('name', nbnf_1.nodeToString(property), overwrites, property);
            }
            else {
                overwrite('fillMode', getFillMode_1.getFillMode(nbnf_1.nodeToString(property)), overwrites, property);
            }
            break;
        case 'EasingFunction':
            if ('timingFunction' in overwrites) {
                overwrite('name', nbnf_1.nodeToString(property), overwrites, property);
            }
            else {
                overwrite('timingFunction', getTimingFunction_1.getTimingFunction(property.nodes), overwrites, property);
            }
            break;
        case 'SingleAnimationIterationCount': {
            const value = nbnf_1.nodeToString(property);
            overwrite('iterationCount', value === 'infinite' ? Infinity : parseInt(value, 10), overwrites, property);
            break;
        }
        case 'SingleAnimationDirection':
            overwrite('direction', getDirection_1.getDirection(nbnf_1.nodeToString(property)), overwrites, property);
            break;
        default:
            throw new Error(`Invalid <single-animation>: ${nbnf_1.nodeToString(property)}`);
    }
    return overwrites;
};