"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCubicBezierFunction = void 0;
const nbnf_1 = require("@nlib/nbnf");
const types_1 = require("./types");
const constants_1 = require("./constants");
exports.getCubicBezierFunction = (timingFunctionNode) => {
    let points = null;
    const firstNode = timingFunctionNode.nodes[0];
    if (nbnf_1.isASTRuleNode(firstNode)) {
        const buffer = [];
        let index = 0;
        for (const node of firstNode.nodes) {
            if (nbnf_1.isASTRuleNode(node) && node.name === 'CubicBezierEasingFunctionCoordinate') {
                buffer[index++] = parseFloat(nbnf_1.nodeToString(node));
                if (4 <= index) {
                    points = [buffer[0], buffer[1], buffer[2], buffer[3]];
                    break;
                }
            }
        }
    }
    else {
        points = constants_1.knownCubicBezierPoints[nbnf_1.nodeToString(timingFunctionNode)] || null;
    }
    if (!points) {
        throw new Error(`Invalid <cubic-bezier-function>: ${nbnf_1.nodeToString(timingFunctionNode)}`);
    }
    return { type: types_1.CSSTimingFunctionType.cubicBezier, points };
};