"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStepFunction = void 0;
const nbnf_1 = require("@nlib/nbnf");
const types_1 = require("./types");
const getStepPosition_1 = require("./getStepPosition");
exports.getStepFunction = (timingFunctionNode) => {
    let stepCount = null;
    let stepPosition = null;
    const firstNode = timingFunctionNode.nodes[0];
    if (nbnf_1.isASTRuleNode(firstNode)) {
        stepPosition = types_1.CSSStepPosition.end;
        for (const node of firstNode.nodes) {
            if (nbnf_1.isASTRuleNode(node)) {
                switch (node.name) {
                    case 'StepEasingFunctionStepCount':
                        stepCount = parseInt(nbnf_1.nodeToString(node), 10);
                        break;
                    case 'StepPosition':
                        stepPosition = getStepPosition_1.getStepPosition(nbnf_1.nodeToString(node));
                        break;
                    default:
                }
            }
        }
    }
    else {
        switch (nbnf_1.nodeToString(timingFunctionNode)) {
            case types_1.CSSDefinedStepName.stepStart:
                stepCount = 1;
                stepPosition = types_1.CSSStepPosition.jumpStart;
                break;
            case types_1.CSSDefinedStepName.stepEnd:
                stepCount = 1;
                stepPosition = types_1.CSSStepPosition.jumpEnd;
                break;
            default:
        }
    }
    if (stepCount && stepPosition && (stepPosition !== types_1.CSSStepPosition.jumpNone || 1 < stepCount)) {
        return {
            type: types_1.CSSTimingFunctionType.step,
            stepCount,
            stepPosition,
        };
    }
    throw new Error(`Invalid <step-function>: ${nbnf_1.nodeToString(timingFunctionNode)}`);
};