"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeTimingFunction = exports.serializeStepTimingFunction = exports.serializeCubicBezierTimingFunction = void 0;
const types_1 = require("./types");
const isSameCubicBezierPoints_1 = require("./isSameCubicBezierPoints");
const constants_1 = require("./constants");
exports.serializeCubicBezierTimingFunction = (timingFunction) => [
    types_1.CSSDefinedCubicBezierName.ease,
    types_1.CSSDefinedCubicBezierName.easeIn,
    types_1.CSSDefinedCubicBezierName.easeOut,
    types_1.CSSDefinedCubicBezierName.easeInOut,
].find((name) => isSameCubicBezierPoints_1.isSameCubicBezierPoints(timingFunction.points, constants_1.knownCubicBezierPoints[name])) || `cubic-bezier(${timingFunction.points.join(',')})`;
exports.serializeStepTimingFunction = (timingFunction) => {
    if (timingFunction.stepCount === 1) {
        switch (timingFunction.stepPosition) {
            case types_1.CSSStepPosition.start:
                return types_1.CSSDefinedStepName.stepStart;
            case types_1.CSSStepPosition.end:
                return types_1.CSSDefinedStepName.stepEnd;
            default:
        }
    }
    if (timingFunction.stepPosition === types_1.CSSStepPosition.end) {
        return `steps(${timingFunction.stepCount})`;
    }
    return `steps(${timingFunction.stepCount}, ${timingFunction.stepPosition})`;
};
exports.serializeTimingFunction = (timingFunction) => {
    switch (timingFunction.type) {
        case types_1.CSSTimingFunctionType.linear:
            return types_1.CSSTimingFunctionType.linear;
        case types_1.CSSTimingFunctionType.cubicBezier:
            return exports.serializeCubicBezierTimingFunction(timingFunction);
        case types_1.CSSTimingFunctionType.step:
            return exports.serializeStepTimingFunction(timingFunction);
        default:
            throw new Error(`Invalid timingFunction: ${JSON.stringify(timingFunction)}`);
    }
};