"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformDeclarations = void 0;
const parseAnimationShorthand_1 = require("../parser/parseAnimationShorthand");
const serializeAnimationShorthand_1 = require("../parser/serializeAnimationShorthand");
const getMatchedImport_1 = require("./getMatchedImport");
exports.transformDeclarations = ({ root, transformResult, mangler, imports, rawPrefix }) => {
    const getRenamed = (name) => {
        if (name.startsWith(rawPrefix)) {
            return name.slice(rawPrefix.length);
        }
        const imported = getMatchedImport_1.getMatchedImport(name, imports);
        if (imported) {
            return mangler(imported.from, 'keyframes', imported.key);
        }
        return transformResult.keyframes[name];
    };
    root.walkDecls((declaration) => {
        const { prop } = declaration;
        if (prop === 'animation-name') {
            const renamed = getRenamed(declaration.value);
            if (renamed) {
                declaration.value = renamed;
            }
        }
        else if (prop === 'animation') {
            const animation = parseAnimationShorthand_1.parseAnimationShorthand(declaration.value);
            const renamed = getRenamed(animation.name);
            if (renamed) {
                animation.name = renamed;
                declaration.value = serializeAnimationShorthand_1.serializeCSSAnimationShorthand(animation);
            }
        }
    });
};